function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactEditor = require('@toast-ui/react-editor');
var uml = _interopDefault(require('@toast-ui/editor-plugin-uml'));
var colorSyntax = _interopDefault(require('@toast-ui/editor-plugin-color-syntax'));
var chart = _interopDefault(require('@toast-ui/editor-plugin-chart'));
var codeSyntaxHighlight = _interopDefault(require('@toast-ui/editor-plugin-code-syntax-highlight'));
var tableMergedCell = _interopDefault(require('@toast-ui/editor-plugin-table-merged-cell'));
var Prism = _interopDefault(require('prismjs'));
require('prismjs/components/prism-java.min.js');
require('prismjs/components/prism-python.min.js');
require('prismjs/components/prism-jsx.min.js');
require('prismjs/components/prism-c.min.js');
require('prismjs/components/prism-cpp.min.js');
require('prismjs/components/prism-javascript.min.js');
require('prismjs/components/prism-json.min.js');
require('prismjs/components/prism-bash.min.js');
require('prismjs/components/prism-diff.min.js');
require('prismjs/components/prism-docker.min.js');
require('prismjs/components/prism-typescript.min.js');
require('prismjs/components/prism-tsx.min.js');
var _katex = _interopDefault(require('katex'));
require('katex/dist/contrib/mhchem.js');
var latex_js = require('latex.js');
var mermaid = _interopDefault(require('mermaid'));

var items = [['heading', 'bold', 'italic', 'strike'], ['hr', 'quote'], ['ul', 'ol', 'task', 'indent', 'outdent'], ['table', 'image', 'link'], ['code', 'codeblock']];
function toggleFullScreen(editorRef) {
  var imageUrl = 'https://res.cloudinary.com/dsabyte/image/upload/v1625072659/toast/fullscreen-svgrepo-com_y4avfz.svg';
  var button = document.createElement('button');
  button.className = "toastui-editor-toolbar-icons " + 'full-screen';
  button.style.backgroundImage = 'none';
  button.style.margin = '0';
  button.innerHTML = "<img src=" + imageUrl + " alt='full screen  button'></img>";
  button.addEventListener('click', function (_) {
    if (!editorRef || !editorRef.current) return;
    var el = editorRef.current.getRootElement();
    if (el.style.height != '100vh') el.style = 'height:100vh; width:100vw; position:fixed;z-index:100000;top:0px;left:0px;background-color:white;';else el.style = 'height:400px;';
  });
  return button;
}
function previewStyleButton(handleClick) {
  var imageUrl = 'https://res.cloudinary.com/dsabyte/image/upload/v1625105428/toast/preview-style_vevyy6.svg';
  var button = document.createElement('button');
  button.className = "toastui-editor-toolbar-icons " + 'preview-style-button';
  button.style.backgroundImage = 'none';
  button.style.margin = '0';
  button.innerHTML = "<img src=" + imageUrl + " alt='preview-style-button'></img>";
  button.addEventListener('click', handleClick);
  return button;
}
function darkMode(handleClick) {
  var imageUrl = 'https://res.cloudinary.com/dsabyte/image/upload/v1625109031/toast/moon-svgrepo-com_xmuyw5.svg';
  var button = document.createElement('button');
  button.className = "toastui-editor-toolbar-icons " + 'dark-mode-button';
  button.style.backgroundImage = 'none';
  button.style.margin = '0';
  button.innerHTML = "<img src=" + imageUrl + " alt='dark-mode-button'></img>";
  button.addEventListener('click', handleClick);
  return button;
}
function tocMake(editorRef) {
  var baseImage = 'https://res.cloudinary.com/dsabyte/image/upload/v1636458893/toast/toc-1_m4orqu.svg';
  var errorImage = 'https://res.cloudinary.com/dsabyte/image/upload/v1636459134/toast/error_ujbprt.svg';
  var okImage = 'https://res.cloudinary.com/dsabyte/image/upload/v1636459135/toast/check_zm0a5w.svg';
  var button = document.createElement('button');
  button.className = "toastui-editor-toolbar-icons " + 'toc-make-button';
  button.style.backgroundImage = 'none';
  button.style.margin = '0';
  button.innerHTML = "<img src=" + baseImage + " alt='dark-mode-button'></img>";
  button.addEventListener('click', function () {
    try {
      var _editorRef$current, _editorRef$current$ge;

      var copy = require('copy-to-clipboard');

      var toc = require('md-to-toc');

      var md = (editorRef === null || editorRef === void 0 ? void 0 : (_editorRef$current = editorRef.current) === null || _editorRef$current === void 0 ? void 0 : (_editorRef$current$ge = _editorRef$current.getInstance()) === null || _editorRef$current$ge === void 0 ? void 0 : _editorRef$current$ge.getMarkdown()) || '';
      var tocContent = toc(md, {
        append: '\n_(TOC generated by @dsabyte)_',
        firsth1: false,
        slugify: function slugify(anchor) {
          return anchor.replace(/[^\w\s]/gi, ' ').trim().replace(/ +/g, ' ').split(' ').join('-').toLocaleLowerCase();
        }
      }).content;
      var copied = copy(tocContent);
      if (copied) button.innerHTML = "<img src=" + okImage + " alt='dark-mode-button'></img>";else throw 'Copy Error';
    } catch (e) {
      console.log(e);
      button.innerHTML = "<img src=" + errorImage + " alt='dark-mode-button'></img>";
    } finally {
      setTimeout(function () {
        button.innerHTML = "<img src=" + baseImage + " alt='dark-mode-button'></img>";
      }, 500);
    }
  });
  return button;
}

var reWidgetRule = /\[(@\S+)\]\((\S+)\)/;
var rules = [{
  rule: reWidgetRule,
  toDOM: function toDOM(text) {
    var rule = reWidgetRule;
    var matched = text.match(rule);
    var span = document.createElement('span');
    span.innerHTML = "<a class=\"widget-anchor\" href=\"" + matched[2] + "\">" + matched[1] + "</a>";
    return span;
  }
}];

var mermaidAPI = mermaid.mermaidAPI;
var inlineRenderRegex = {
  youtube: /\s*youtube\s*:.+/i
};

var isYoutube = function isYoutube(str) {
  return inlineRenderRegex.youtube.test(str);
};

var removeFrameCode = function removeFrameCode(code, str) {
  var _str$replace;

  var regex = new RegExp('\\s*' + code + '\\s*:');
  return str === null || str === void 0 ? void 0 : (_str$replace = str.replace(regex, '')) === null || _str$replace === void 0 ? void 0 : _str$replace.trim();
};

var getFrame = function getFrame(src) {
  return "\n<iframe width=\"100%\" height=\"400\"\n    src=\"" + src + "\"\n    allowfullscreen=\"allowfullscreen\"\n    mozallowfullscreen=\"mozallowfullscreen\" \n    msallowfullscreen=\"msallowfullscreen\" \n    oallowfullscreen=\"oallowfullscreen\" \n    webkitallowfullscreen=\"webkitallowfullscreen\"\n>\nThe fallback\n</iframe>\n";
};

function renderMath(str) {
  var html = _katex.renderToString(str, {
    throwOnError: false,
    displayMode: true
  });

  return html;
}

function getInlineMath(str) {
  var prevIdx = 0;
  var nextIdx = -1;

  while (true) {
    prevIdx = str.indexOf('$', prevIdx);
    nextIdx = str.indexOf('$', prevIdx + 1);
    if (nextIdx == -1 || prevIdx == -1) break;
    str = str.replace(str.substr(prevIdx, nextIdx - prevIdx + 1), renderMath(str.substr(prevIdx + 1, nextIdx - prevIdx - 1)));
    if (nextIdx !== -1) prevIdx = nextIdx + 1;
  }

  return str;
}

var renderer = {
  heading: function heading(node, context) {
    var level = node.level;
    var tagName = "h" + level;
    var id = node.firstChild && node.firstChild.literal ? node.firstChild.literal : '';
    id = id.replace(/[^\w\s]/gi, ' ').trim().replace(/ +/g, ' ').split(' ').join('-').toLocaleLowerCase();

    if (context.entering) {
      return {
        type: 'openTag',
        tagName: tagName,
        attributes: {
          id: id
        }
      };
    }

    return {
      type: 'closeTag',
      tagName: tagName,
      attributes: {
        id: id
      }
    };
  },
  text: function text(node, context) {
    return {
      type: 'html',
      content: getInlineMath(node.literal)
    };
  },
  link: function link(node, context) {
    var origin = context.origin,
        entering = context.entering;
    var result = origin();

    if (entering && !result.attributes.href.startsWith('#')) {
      result.attributes.target = '_blank';
    }

    return result;
  },
  katex: function katex(node) {
    var html;

    try {
      html = _katex.renderToString(node.literal, {
        throwOnError: false,
        displayMode: true
      });
    } catch (e) {
      html = "\n        <pre>\n        <code>" + e + "</code>\n        </pre>\n        ";
    }

    return [{
      type: 'openTag',
      tagName: 'div',
      outerNewLine: true,
      classNames: ['math-block']
    }, {
      type: 'html',
      content: html
    }, {
      type: 'closeTag',
      tagName: 'div',
      outerNewLine: true
    }];
  },
  latex: function latex(node) {
    var html;

    try {
      var generator = new latex_js.HtmlGenerator({
        hyphenate: false
      });

      var _parse$htmlDocument = latex_js.parse(node.literal, {
        generator: generator
      }).htmlDocument(),
          body = _parse$htmlDocument.body;

      html = body.innerHTML;
    } catch (e) {
      html = "\n        <pre>\n        <code>" + e + "</code>\n        </pre>\n        ";
    }

    return [{
      type: 'openTag',
      tagName: 'div',
      outerNewLine: true,
      classNames: ['math-block']
    }, {
      type: 'html',
      content: html
    }, {
      type: 'closeTag',
      tagName: 'div',
      outerNewLine: true
    }];
  },
  mermaid: function mermaid(node) {
    var html = '';
    mermaidAPI.render('mermaid', node.literal, function (h) {
      html = h;
    });
    return [{
      type: 'openTag',
      tagName: 'div',
      outerNewLine: true,
      classNames: ['mermaid-block']
    }, {
      type: 'html',
      content: html
    }, {
      type: 'closeTag',
      tagName: 'div',
      outerNewLine: true
    }];
  },
  embed: function embed(node) {
    try {
      var _node$literal, _node$literal$split$, _node$literal2, _node$literal2$split$;

      if (!node.literal || !/\s*\w+\s*:.+/gm.test(node.literal)) throw 'Invalid args';
      var src = isYoutube(node.literal) ? "https://www.youtube.com/embed/" + ((_node$literal = node.literal) === null || _node$literal === void 0 ? void 0 : (_node$literal$split$ = _node$literal.split(':')[1]) === null || _node$literal$split$ === void 0 ? void 0 : _node$literal$split$.trim()) : removeFrameCode((_node$literal2 = node.literal) === null || _node$literal2 === void 0 ? void 0 : (_node$literal2$split$ = _node$literal2.split(':')[0]) === null || _node$literal2$split$ === void 0 ? void 0 : _node$literal2$split$.trim(), node.literal);
      var allowedHosts = ['www.linkedin.com', 'codepen.io', 'stackoverflow.com', 'codesandbox.io', 'www.youtube.com', 'replit.com'];
      if (!allowedHosts.includes(new URL(src).hostname)) throw 'Invalid host name';
      var frame = getFrame(src);
      return [{
        type: 'openTag',
        tagName: 'div',
        outerNewLine: true
      }, {
        type: 'html',
        content: frame
      }, {
        type: 'closeTag',
        tagName: 'div',
        outerNewLine: true
      }];
    } catch (e) {
      console.log(e);
      return [{
        type: 'openTag',
        tagName: 'div',
        outerNewLine: true
      }, {
        type: 'html',
        content: "<a href=\"https://www.dsabyte.com/posts/blog/Embedding-iframe-on-dsabyte-online-editor/617512c844214ad4632bbe16\" target=\"_blank\">Learn more about embedding content on @dsabyte</a>"
      }, {
        type: 'closeTag',
        tagName: 'div',
        outerNewLine: true
      }];
    }
  },
  htmlBlock: {
    details: function details(node) {
      return [{
        type: 'html',
        content: node.childrenHTML
      }];
    }
  },
  htmlInline: {
    b: function b(node) {
      console.log(node);
    }
  }
};

var umlOptions = {
  rendererURL: 'https://www.plantuml.com/plantuml/svg/'
};
var chartOptions = {
  minWidth: 100,
  maxWidth: 500,
  minHeight: 100,
  maxHeight: 300
};

var makeFullScreenInBrowser = function makeFullScreenInBrowser(editorRef) {
  if (!editorRef || !editorRef.current) return;
  var el = editorRef.current.getRootElement();
  if (el.style.height != '100vh') el.style = 'height:100vh; width:100vw; position:fixed;z-index:100000;top:0px;left:0px;background-color:white;';else el.style = 'height:400px;';
};

var insertKatex = function insertKatex(editorRef) {
  if (!editorRef || !editorRef.current) return;
  editorRef.current.getInstance().insertText("\n$$katex\n\n$$\n");
};

var insertUML = function insertUML(editorRef) {
  if (!editorRef || !editorRef.current) return;
  editorRef.current.getInstance().insertText("\n$$uml\n\n$$\n");
};

var insertInlineMath = function insertInlineMath(editorRef) {
  if (!editorRef || !editorRef.current) return;

  var _editorRef$current$ge = editorRef.current.getInstance().getSelection(),
      start = _editorRef$current$ge[0],
      end = _editorRef$current$ge[1];

  var selectedText = editorRef.current.getInstance().getSelectedText(start, end);
  editorRef.current.getInstance().replaceSelection("$" + selectedText + "$", start, end);
};

function MDE10(_ref) {
  var getMd = _ref.getMd,
      getHTML = _ref.getHTML,
      getEditorRef = _ref.getEditorRef,
      uploadImage = _ref.uploadImage,
      initialValue = _ref.initialValue,
      theme = _ref.theme,
      initialEditType = _ref.initialEditType,
      previewStyleType = _ref.previewStyleType,
      height = _ref.height,
      toolbarItems = _ref.toolbarItems;
  var editorRef = React.useRef(null);

  var toggleDarkMode = function toggleDarkMode() {
    var el = editorRef.current.getRootElement().getElementsByClassName('toastui-editor-defaultUI')[0];
    if (el.classList.contains('toastui-editor-dark')) el.classList.remove('toastui-editor-dark');else el.classList.add('toastui-editor-dark');
  };

  var togglePreviewStyle = function togglePreviewStyle() {
    var previewStyle = editorRef.current.getInstance().getCurrentPreviewStyle();
    if (previewStyle === 'vertical') editorRef.current.getInstance().changePreviewStyle('tab');else editorRef.current.getInstance().changePreviewStyle('vertical');
    editorRef.current.getInstance().changeMode('markdown');
  };

  var getEmptyStringIfUndefined = function getEmptyStringIfUndefined(str) {
    return str || '';
  };

  var mdChange = function mdChange() {
    var _editorRef$current, _editorRef$current$ge2, _editorRef$current2;

    getMd && getMd(getEmptyStringIfUndefined(editorRef === null || editorRef === void 0 ? void 0 : (_editorRef$current = editorRef.current) === null || _editorRef$current === void 0 ? void 0 : (_editorRef$current$ge2 = _editorRef$current.getInstance()) === null || _editorRef$current$ge2 === void 0 ? void 0 : _editorRef$current$ge2.getMarkdown()));
    getHTML && getHTML(getEmptyStringIfUndefined(editorRef === null || editorRef === void 0 ? void 0 : (_editorRef$current2 = editorRef.current) === null || _editorRef$current2 === void 0 ? void 0 : _editorRef$current2.getRootElement().getElementsByClassName('toastui-editor-contents')[0].innerHTML));
  };

  var onKeydown = function onKeydown(_, e) {
    if (e.altKey && e.key === 'm') {
      insertInlineMath(editorRef);
    }

    if (e.ctrlKey && e.shiftKey && e.key === 'K') {
      insertKatex(editorRef);
    }

    if (e.ctrlKey && e.shiftKey && e.key === 'U') {
      insertUML(editorRef);
    }
  };

  React.useEffect(function () {
    var keyEventLitener = function keyEventLitener(e) {
      if (e.ctrlKey && e.shiftKey && e.key === 'F') {
        makeFullScreenInBrowser(editorRef);
      }
    };

    document.body.addEventListener('keydown', keyEventLitener);
    return function () {
      document.body.removeEventListener('keydown', keyEventLitener);
    };
  }, []);
  React.useEffect(function () {
    getEditorRef(editorRef);
  }, [editorRef]);
  return /*#__PURE__*/React__default.createElement(reactEditor.Editor, {
    ref: editorRef,
    initialValue: initialValue,
    previewStyle: previewStyleType,
    height: height,
    initialEditType: initialEditType,
    useCommandShortcut: true,
    theme: theme,
    widgetRules: rules,
    onBlur: mdChange,
    onKeydown: onKeydown,
    autofocus: false,
    hideModeSwitch: true,
    hooks: {
      addImageBlobHook: function addImageBlobHook(blob, callback) {
        uploadImage(blob).then(function (url) {
          return callback(url, 'Put alt text here...');
        })["catch"](function (err) {
          console.log(err);
          callback('Server error!', 'Directly paste image link.');
        });
        return false;
      }
    },
    toolbarItems: toolbarItems.length == 0 ? [].concat(items, [[{
      el: toggleFullScreen(editorRef),
      tooltip: 'Full Screen'
    }, {
      el: previewStyleButton(togglePreviewStyle),
      tooltip: 'Preview Mode'
    }, {
      el: tocMake(editorRef),
      tooltip: 'Make TOC'
    }, {
      el: darkMode(toggleDarkMode),
      tooltip: 'Dark Mode'
    }], ['scrollSync']]) : toolbarItems,
    customHTMLRenderer: renderer,
    plugins: [[uml, umlOptions], colorSyntax, [chart, chartOptions], tableMergedCell, [codeSyntaxHighlight, {
      highlighter: Prism
    }]]
  });
}
MDE10.defaultProps = {
  initialValue: '# Hi, i am  [Rahul](https://ats1999.github.io)',
  theme: 'dark',
  initialEditType: 'markdown',
  previewStyleType: 'vertical',
  height: '400px',
  toolbarItems: [],
  getEditorRef: function getEditorRef() {}
};

module.exports = MDE10;
//# sourceMappingURL=index.js.map
